## [4.3.1](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/branchCompare?baseVersion=GTv4.3.0&targetVersion=GTv4.3.1&_a=files) (2025-10-24)


### Bug Fixes

* dummy build to pull latests base image [#11162](https://dev.azure.com/seven2one/Seven2one.Questra/_workitems/edit/11162/) ([e0111c9](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/e0111c9fb8f9015117cd9fea3028838ef430fe41))

# [4.3.0](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/branchCompare?baseVersion=GTv4.2.1&targetVersion=GTv4.3.0&_a=files) (2025-10-22)


### Features

* SBOM generation, CVE detection and upload to dependencytrack [#10599](https://dev.azure.com/seven2one/Seven2one.Questra/_workitems/edit/10599/) ([4322796](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/4322796540a74bf5146d5d29fecb9909b3943a6a))

## [4.2.1](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/branchCompare?baseVersion=GTv4.2.0&targetVersion=GTv4.2.1&_a=files) (2025-10-14)


### Bug Fixes

* automatically add external rights to SuperAdmin group ([eed2f3f](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/eed2f3f9d7979701308f7222a5c8cfcdb7c124f7))

# [4.2.0](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/branchCompare?baseVersion=GTv4.1.2&targetVersion=GTv4.2.0&_a=files) (2025-10-13)


### Features

* http(s) gzip/brotli response compression support ([7377d49](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/7377d492750d70d01c5f5622ffe7a11ad69b94d8))

## [4.1.2](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/branchCompare?baseVersion=GTv4.1.1&targetVersion=GTv4.1.2&_a=files) (2025-09-18)


### Bug Fixes

* argo template invalid json when build error ([53b0520](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/53b052057da7e5f653a6d923fb532f1020f1d394))
* remove global.json for pinning net sdk ([82fa1d2](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/82fa1d28b05c22abbce359227b0345fac5140b74))

## [4.1.1](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/branchCompare?baseVersion=GTv4.1.0&targetVersion=GTv4.1.1&_a=files) (2025-09-04)


### Bug Fixes

* add missing files ([16f2f56](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/16f2f56622147ea2bde7880e59018cde79c1aae6))

# [4.1.0](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/branchCompare?baseVersion=GTv4.0.1&targetVersion=GTv4.1.0&_a=files) (2025-08-22)


### Features

* domain errors support by console output of scripts in the pattern of  ##automation[domainstatus]Succeeded or ##automation[domainstatus status=Failed;message=Validation error] ([1519771](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/15197719564ea37b26d4aeadc67150e23c27b9e4))

## [4.0.1](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/branchCompare?baseVersion=GTv4.0.0&targetVersion=GTv4.0.1&_a=files) (2025-08-08)


### Bug Fixes

* start requestes workflow resilience. this can happen if you stop the service when a workflow is started but the db transaction is not being executed while shut down. handled wrong exception. now working ([34f5bcc](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/34f5bcc1fe0deb357ed0c759cc56e5b5625ae554))

# [4.0.0](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/branchCompare?baseVersion=GTv3.0.0&targetVersion=GTv4.0.0&_a=files) (2025-08-08)


* Merged PR 13301: BREAKING CHANGE: Rebranding from TechStack to Questra ([ec0088c](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/ec0088cd5baf5517a4fe9cfce20997942138d9f7)), closes [#10876](https://dev.azure.com/seven2one/Seven2one.Questra/_workitems/edit/10876/)


### BREAKING CHANGES

* Rebranding from TechStack to Questra

# [3.0.0](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/branchCompare?baseVersion=GTv2.0.0&targetVersion=GTv3.0.0&_a=files) (2025-08-06)


### Bug Fixes

* add automation prefix to serviceInfo ([d995a08](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/d995a088c787fa7a02c23938fc5cabd6cb9c6370))
* add explicit questra prefix ([cba11ce](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/cba11ce8a570f6931fe3bea5d2462582c5a0ccb5))
* lots of fixes and improvements based on feedback ([3006eca](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/3006eca9b4134b4c18cfa5a667ecc590e185ec9b))
* nuget source ([8e0912b](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/8e0912bedd1c68eed796716daed32925248bbd84))
* pipeline ([42f01e0](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/42f01e0b9e6eea9c26317cef108777c129346edd))
* scheduledExecutions only return executions for active schedules ([e1c6923](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/e1c6923bf534cb0a43bfbec64d4316a2f89e8146))
* update workflow templates (buildkit and service account) ([db746b6](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/db746b60dc5451c088df527ef01b41961af4e59e))


### Features

* add authorization for external rights (wip) ([daf3daf](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/daf3dafb1aa7f029d6824342335489984590c393))
* update and create repository requires a remote element which contains url and credentials ([e7ce811](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/e7ce8116abbdc82f9eb2327bc354a503b86be202))


### BREAKING CHANGES

* GQL adjustments, DB adjustments

# [2.0.0](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/branchCompare?baseVersion=GTv1.0.0&targetVersion=GTv2.0.0&_a=files) (2025-07-10)


### Bug Fixes

* [#10162](https://dev.azure.com/seven2one/Seven2one.Questra/_workitems/edit/10162/) replaced DateTime fields by DateTimeOffsets and convert incoming values to UTC ([4e7cbf2](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/4e7cbf262dfaf46d594849c5b8728d57b0fee6e5))
* ability to rebuild automations, reslience infinite loop fix ([9a7fda7](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/9a7fda70430bdd315bfd4a2361e911117a1430cc))
* active deadline in minutes. not hours ([107409f](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/107409fb5b3f111a3ac3bc9b0e584ce10c0d6e75))
* add id suffix when the field is an id field ([7bc6cdb](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/7bc6cdb383898485c0786872840ca50b1c06b6c7))
* change model to represent real world: workspace -> synchronization -> automation -> automation arguments ([24f3bb4](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/24f3bb46bb5ad91c55c8d842a05edf589b37502a))
* check service account existence before assignment ([4329e8e](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/4329e8e69665c70ac996a254e913a1c0268e22f2))
* convert to correct time zone on scheduled executions ([da21e68](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/da21e6858b95538fe45d6ba25d1a3d4b818a3bce))
* Don't respect costs of gql response using resolver. Not recommented but no other way possible by current arch. https://chillicream.com/docs/hotchocolate/v15/security/cost-analysis ([1adaddf](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/1adaddf286d51a3b28cf1804354419c63d015358))
* error handling fore execution refresh, limit the number of lookups for pending executions ([faa57c8](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/faa57c8c2a48ffa9d2e13ab2e4efc81b5b390cee))
* error output in sync template ([1844d75](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/1844d75ee2d7bab932516142eb865b55790ba74f))
* fix warning ([a465013](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/a465013bcdd4371126fdd4e38692740d33b5d4ef))
* fixed argo client base url, removed debug stuff, added config to force developer exception page ([8bf2c98](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/8bf2c98b177e5d6f2cdd9927366c22a3bf855ebb))
* fixed bug with empty reference ([e4f4155](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/e4f4155c239e6beff1532152d18ab9b0f34cc1af))
* fixed bug with reading status right after starting a sync ([990cc17](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/990cc17e2014b07a4d75e3a4d072c71cd8620bc9))
* fixed comit in workspace output ([b825154](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/b825154ee859c821f54f7f9290af0a8ab6df848e))
* fixed output value of delete schedule ([f9fd5ba](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/f9fd5ba3a1d1161abe4509bcec3ccbd4fa478adb))
* fixed sorting of executions by force context clone ([b80b09e](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/b80b09e3511ee4b703a0a8b15195d9d7099b05ec))
* get rid for workaround for pgsql computed datetimeoffset conversion https://github.com/JasperFx/marten/issues/3590 ([bd65665](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/bd65665753f1b41d82a71bb7c61bea0a4264b37b))
* gql schema error ([8e36142](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/8e36142da1e100447a8838a5c2b23a71449b364a))
* refresh executions independed from output / status filter ([6a778a1](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/6a778a1a73c26644e02b2f7b94f939eb44c1504b))
* refresh when no take argument given ([e3ea568](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/e3ea56804846ad0db82e4bf44212d6c8c066dad1))
* Remove automations when schedule is being removed ([4adca11](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/4adca1183fef477f38c9690d5a6f61a343d01c4d))
* respect order and take on refresh execution ([131af8f](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/131af8f5fdb2bb8ca741b18bcb4bcbcb728713d1))
* some fixes and tests ([3626fae](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/3626fae9dc5b1a8d880f827a3dd75884c3504dcd))
* warnings ([86ec01a](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/86ec01a0552a8dfa21d80d146e2ad1dfff6cdbd0))
* warnings ([3f77b2f](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/3f77b2f1d9dbccb4c3397e8c42d61bb0fa2e52e9))


### chore

* refactoring ([41a98d9](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/41a98d9d85873ab631818e9f363de494b7b0e44c))


### Features

* [#10163](https://dev.azure.com/seven2one/Seven2one.Questra/_workitems/edit/10163/) implemented schedule trigger using quartz ([bd18bf1](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/bd18bf1096a3a543a5d357df10c9622933a228e6))
* [#10164](https://dev.azure.com/seven2one/Seven2one.Questra/_workitems/edit/10164/) implemented next fire times query ([471a51e](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/471a51efdd59bb983378e007cbb9b38b18bfd28c))
* [#10167](https://dev.azure.com/seven2one/Seven2one.Questra/_workitems/edit/10167/) removed  forced workspace argument from schedules query ([4ed195e](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/4ed195e303930a1df9dfd1cd4c14c56c5afb573f))
* added Indices ([58619e8](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/58619e8b22b47d780b16cb8f0f7740f1d4ea1c5d))
* assign service account command / api ([3aa56cd](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/3aa56cddf0accf3a898befcd0cdf404b8dea2047))
* extended execution informatiions, keep executions when deleting the workspace ([8adee4d](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/8adee4d30f622596e3c3a125134377e6b2c639d1))
* filter / sort / paging for schedules, fixed fk bug ([3810d4d](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/3810d4d7514595bc88f2a4798c76e9c087d7af2d))
* implemented exceptions ([f3bd7fc](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/f3bd7fc8202949720b73ab0e638d6d3193ce04cd))
* implemented execution logic, replace, replace input objects by single arguments in graphql api ([776f408](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/776f408ebd88d6de28fa80922c608a0e58b1757c))
* improved validation for schedules, allowed to override service account for execution / schedules ([1acc350](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/1acc350444c23587ee00670fe5bcedf99279bb22))
* label for kubernetes secrets / argo workflows ([4b035e4](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/4b035e4c3520bb4b128f05a6b2220e9f2a464aeb))
* pagination like dyno with GQL Connections ([2ebc454](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/2ebc454b12f5c2e04f36208e1c810bb38789b3c0))
* parameter validation (wip: regex, error codes) ([e458971](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/e458971e9e884cf130629df303adf6106b960dc2))
* pass arguments by name ([5f646bb](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/5f646bbcab87490a4f3f18e79c36af24f84778d4))
* refresh sychronizations on list / edit automations, store reference to last sync id ([21eea32](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/21eea32ade83d45b879a3c8b8d2ac9936fc6040d))
* relogin, execute, kubernetes project, renamed access token of service accounts to password, regenerate ssh token ([2135d2b](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/2135d2b695531bb58e6b51614c7b70438031b072))
* removed forainkey constraint for executions to prevent deleting them ([660af60](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/660af60e098c8683b54ab9c3f7831519f6e5f14d))
* Removed workspace restriction for execution / automation listing, load child objects using DataLoaders, Handle references correctly in graphql filters ([0721b70](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/0721b7076f03d5a7aa591ca608458bb12fcf8ec0))
* sychronization integration, replaced strings by guids, add cascading fk deletions, saved secrets base64 ([83b71dd](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/83b71ddbb0a05d1926b9b79b56eb31510640c68e))
* unified list queries, filter, sorting, paging at query level ([193d89e](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/193d89e17ba52ab42523261ddf11c087e36f54ed))
* validation of input fields ([c655938](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/c655938ea4ad796b089e670bc035983facf48e4a))


### BREAKING CHANGES

* Database schema modified. GQL schema modified

# 1.0.0 (2024-11-27)


### Bug Fixes

* add missing dockerfile ([2db2818](https://dev.azure.com/seven2one/Seven2one.Questra/_git/S2O.Questra.Automation/commit/2db2818cc50750726b8ab2095f256f869b8c7ce4))
